Crate nami_core

Crate nami_core 

Core components for the Nami framework.

Modules

collection
Collection types for Nami.
dictionary
A module providing a reactive dictionary data structure. This module defines the Dictionary trait and a reactive Map implementation that allows watching for changes to key-value pairs.
observe
Optional observability for the reactive graph.
watcher
Watcher Management

Macros

impl_constant
Macro to implement the Signal trait for constant types.

Structs

SignalIdentity
Stable identity for reactive signal instances that own observable state.

Traits

CustomBinding
The CustomBinding trait represents a computable value that can also be set.
Signal
The core trait for reactive system.