pub struct SignalIdentity(/* private fields */);Expand description
Stable identity for reactive signal instances that own observable state.
Implementations
Sourceimpl SignalIdentity
impl SignalIdentity
Sourcepub fn from_rc<T>(value: &Rc<T>) -> Self
pub fn from_rc<T>(value: &Rc<T>) -> Self
Creates an identity from a shared allocation pointer.
The allocation must be tied to the semantic signal instance and be cloned together with that instance.
Sourcepub const fn with_discriminator(self, discriminator: usize) -> Self
pub const fn with_discriminator(self, discriminator: usize) -> Self
Creates a stable derived identity for a property of this signal.
Sourcepub const fn combine(self, other: Self) -> Self
pub const fn combine(self, other: Self) -> Self
Combines two stable signal identities into one deterministic identity.
Sourcepub fn call_site_discriminator<T: 'static>(
caller: &'static Location<'static>,
) -> usize
pub fn call_site_discriminator<T: 'static>( caller: &'static Location<'static>, ) -> usize
Creates a stable discriminator from a call site and semantic wrapper type.