pub trait WatcherGuard: 'static { }Expand description
A guard that ensures proper cleanup of watchers when dropped.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait WatcherGuard: 'static { }A guard that ensures proper cleanup of watchers when dropped.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".