Core components for the Nami framework.
Modules
- collection
- Collection types for Nami.
- dictionary
- A module providing a reactive dictionary data structure.
This module defines the
Dictionarytrait and a reactiveMapimplementation that allows watching for changes to key-value pairs. - observe
- Optional observability for the reactive graph.
- watcher
- Watcher Management
Macros
- impl_
constant - Macro to implement the Signal trait for constant types.
Structs
- Signal
Identity - Stable identity for reactive signal instances that own observable state.
Traits
- Custom
Binding - The
CustomBindingtrait represents a computable value that can also be set. - Signal
- The core trait for reactive system.